@@ -2,7 +2,9 @@
 // #![feature(box_syntax)]
 #![forbid(missing_debug_implementations)]
 #![forbid(missing_crate_level_docs)]
-#![doc = include_str ! ("../readme.md")]
+#![doc = include_str!("../readme.md")]
+#![doc(html_logo_url = "https://avatars.githubusercontent.com/u/67109815")]
+#![doc(html_favicon_url = "https://avatars.githubusercontent.com/u/67109815")]
 
 extern crate core;
 
@@ -12,13 +14,11 @@ mod systems;
 mod traits;
 
 pub use self::{
-    builder::{
-        parser::{utils::*, *},
-        TailwindBuilder,
-    },
+    builder::*,
     systems::{
         accessibility::*, background::*, borders::*, breakpoints::*, colors::*, effects::*, filters::*, flexbox::*, fonts::*,
-        layouts::*, preflight::*, sizing::*, spacing::*, tables::*, transforms::*, transition::*, typography::*,
+        interactivity::*, layouts::*, preflight::*, sizing::*, spacing::*, tables::*, transforms::*, transition::*,
+        typography::*,
     },
     traits::{CssAttribute, ParsedItem, ParsedList, TailwindInstance, TailwindObject},
 };
